@@ -5,7 +5,14 @@ from .rajapinta import Rajapinta
 from .rest import RestYhteys
 from .sanoma import RestKentta, RestValintakentta, RestSanoma
 from .sivutus import SivutettuHaku
-from .tyokalut import ei_syotetty, mittaa, periyta, Rutiini, Valinnainen
+from .tyokalut import (
+  ei_syotetty,
+  mittaa,
+  periyta,
+  Rutiini,
+  sisaluokka,
+  Valinnainen,
+)
 from .yhteys import AsynkroninenYhteys
 
 
